module.exports = defineTest({
	description: 'Renders updates of exported variables for SystemJS output',
	options: {
		output: {
			format: 'system'
		}
	}
});
